DriftViewerFloatingButton class final
Floating button that opens the Drift viewer in the browser or in an in-app WebView.
Only builds a visible widget when kDebugMode is true and DriftDebugServer.port is non-null (server running). Otherwise builds SizedBox.shrink.
Place in a Stack or use DriftViewerOverlay to wrap your app with a default position.
See also: DriftViewerOverlay.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DriftViewerFloatingButton
Constructors
- DriftViewerFloatingButton({Key? key})
-
Creates a floating button that opens the Drift viewer.
const
Properties
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildWebViewRoute(
dynamic settingsOrUriString) → Route< void> - Builds the route for the in-app WebView. Use when registering webViewRouteName.
Constants
- webViewRouteName → const String
-
Route name for the in-app WebView screen. Register in MaterialApp.onGenerateRoute
or MaterialApp.routes so
openInWebViewcan use named routes for deep linking. Example:onGenerateRoute: (s) => s.name?.startsWith(DriftViewerFloatingButton.webViewRouteName) == true ? DriftViewerFloatingButton.buildWebViewRoute(s) : null