DriftViewerFloatingButton constructor
const
DriftViewerFloatingButton({
- Key? key,
Creates a floating button that opens the Drift viewer.
Implementation
const DriftViewerFloatingButton({super.key});
Creates a floating button that opens the Drift viewer.
const DriftViewerFloatingButton({super.key});