DriftViewerOverlay class final

Wraps child in a Stack and overlays a floating button in debug builds that opens the Drift viewer in the browser or WebView.

When kDebugMode is false or DriftDebugServer.port is null, only child is shown. Otherwise a DriftViewerFloatingButton is stacked at alignment with optional margin.

Example:

runApp(DriftViewerOverlay(
  child: MaterialApp(home: MyHomePage()),
));
Inheritance

Constructors

DriftViewerOverlay({Key? key, required Widget child, AlignmentGeometry alignment = AlignmentDirectional.bottomEnd, EdgeInsetsGeometry? margin})
Creates an overlay that wraps child and shows a viewer button when applicable.
const

Properties

alignment AlignmentGeometry
Alignment of the floating button. Defaults to AlignmentDirectional.bottomEnd.
final
child Widget
The widget below the overlay (e.g. your MaterialApp).
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry
Margin around the floating button. Defaults to 16 logical pixels on all sides.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
override
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited